@@ -224,6 +224,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                             "minimum": 0,
                             "type": "integer"
                         },
+                        "plan_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
+                        },
                         "quality": {
                             "additionalProperties": false,
                             "nullable": true,
@@ -349,6 +355,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                             "format": "double",
                             "minimum": 0,
                             "type": "number"
+                        },
+                        "waitlist_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
                         }
                     },
                     "required": [
@@ -597,6 +609,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                         "minimum": 0,
                                         "type": "integer"
                                     },
+                                    "plan_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
+                                    },
                                     "quality": {
                                         "additionalProperties": false,
                                         "nullable": true,
@@ -722,6 +740,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                         "format": "double",
                                         "minimum": 0,
                                         "type": "number"
+                                    },
+                                    "waitlist_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
                                     }
                                 },
                                 "required": [
